# Empire State Run Up

[![Downloads](https://static.pepy.tech/badge/EmpireStateRunUp)](https://pepy.tech/project/EmpireStateRunUp)

![empire_state_runup.png](images/empire_state_runup.png)

![ESRU browser](images/esru_browser.png)



Hello. I wrote an application to analyse the results of the 'Empire State Run Up', 2013 edition, after I ran the race. 

Here you will find my code.

## If you just want to install it

See the previous section called 'Packaging', and then install it on your virtual environment:

```shell
python3 -m venv ~/virtualenv/EmpireStateRunUp
. ~/virtualenv/EmpireStateRunUp/bin/activate
pip install --upgrade pip
python -m build .
pip install --upgrade dist/EmpireStateRunUp-0.0.1-py3-none-any.whl
```

There are 4 scripts that you can run:

* esru_numbers
* esru_outlier
* esru_browser
* esru_plot

If you want to learn more about these programs, please grab a cup of coffe and read the [TUTORIAL](TUTORIAL.md)

## If you are a developer

### Running the code in developer mode

```shell
python3 -m venv ~/virtualenv/EmpireStateRunUp
. ~/virtualenv/EmpireStateRunUp/bin/activate
pip install --upgrade pip
pip install --editable .[dev,lint]
```

#### Modifying the layout without restarting the apps

For example, playing with the 'esru_outlier' application:

```shell
. ~/virtualenv/EmpireStateRunUp/bin/activate
pip install textual-dev
# On another terminal: . ~/virtualenv/EmpireStateRunUp/bin/activate && textual console
textual run --dev empirestaterunup.apps:run_outlier 
```

### Packaging 

```shell
python3 -m venv ~/virtualenv/EmpireStateRunUp
. ~/virtualenv/EmpireStateRunUp/bin/activate
pip install --upgrade pip
pip install --upgrade build
pip install --upgrade wheel
python -m build .
```

### Installation from PiPy

For your user:
```shell
pip install --user EmpireStateRunUp
```

Or using a virtual environment:

```shell
python -m venv ~/virtualenv/EmpireStateRunUp && \
.  ~/virtualenv/EmpireStateRunUp/bin/acvtivate && \
pip install EmpireStateRunUp
```

#### Country codes

I used the files generated by the [ISO-3166-Countries-with-Regional-Codes
](https://github.com/lukes/ISO-3166-Countries-with-Regional-Codes/tree/master) for the flag lookup, using [Regional indicator symbol](https://en.wikipedia.org/wiki/Regional_indicator_symbol).

## Tutorial

Make sure you check the [tutorial](TUTORIAL.md). It explains how this project got started, as well showcases features of the applications.

## Running in server mode

The applications now support running in web server mode. To enable:

```shell
(EmpireStateRunUp) [josevnz@dmaf5 EmpireStateRunUp]$ esru_server --help
usage: esru_server [-h] --application {esru_numbers,esru_outlier,esru_browser} [--port PORT] [--debug] [results ...]

Browse user results

positional arguments:
  results               Race results.

options:
  -h, --help            show this help message and exit
  --application {esru_numbers,esru_outlier,esru_browser}
                        Applications that can run in server mode: ['esru_numbers', 'esru_outlier', 'esru_browser']
  --port PORT           Default port (8000)
  --debug               Enable debug mode

```

```shell
esru_server --application esru_numbers

# Or if you have an external results file:

sru_server --application esru_browser empirestaterunup/results-2023.json
```

## Getting latest race results

I used [athlinks-races](https://pypi.org/project/athlinks-races/) to parse the race results. This is an example of a scrapping session:

```shell
athlinks_races_cli --metadata_rpt /home/josevnz/EmpireStateBuildingRunUp/empirestaterunup/metadata-2023.json --athletes_rpt /home/josevnz/EmpireStateBuildingRunUp/empirestaterunup/results-2023.json --format jsonlines --race_url https://www.athlinks.com/event/382111/results/Event/1062909/Results
athlinks_races_cli --metadata_rpt /home/josevnz/EmpireStateBuildingRunUp/empirestaterunup/metadata-2024.json --athletes_rpt /home/josevnz/EmpireStateBuildingRunUp/empirestaterunup/results-2024.json --format jsonlines --race_url https://www.athlinks.com/event/382111/results/Event/1093108/Results
```
